package com.lagou.lagouee.ui.search.view

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.RecyclerView
import butterknife.BindView
import butterknife.ButterKnife
import butterknife.OnClick
import com.alpha.lagouapk.R
import com.lagou.baselib.analytic.AnalyticHelper
import com.lagou.lagouee.bean.search.NewFilterMoreData
import com.lagou.lagouee.bean.search.SearchFilterData
import com.lagou.lagouee.ui.adapter.VipFilterMoreAdapter
import com.lagou.lagouee.ui.search.FilterDecoration

/**
 * Time：2024/4/24 15:07:37
 * Author：wangjunwei
 * Description：vip 用户更多选项
 */
class VipFilterMoreLayout(context: Context?) : FilterMoreBaseLayout(context) {

    @BindView(R.id.rv_search_filter)
    lateinit var rvSearchFilter: RecyclerView

    private var vipFilterAdapter: VipFilterMoreAdapter? = null
    private var vipFilterMoreData: NewFilterMoreData? = null

    override fun getViewContent(): View {
        return this
    }

    override fun resetFilter() {
        vipFilterAdapter?.resetAll()
    }

    override fun flushUi(type: String) {
        vipFilterAdapter?.flushUi(type)
    }


    override fun init() {
        LayoutInflater.from(context).inflate(R.layout.layout_filter_search_more, this)
        ButterKnife.bind(this)
        initFilterView()
    }

    private fun initFilterView() {
        val gridLayoutManager = GridLayoutManager(context, 3)
        rvSearchFilter.apply {
            layoutManager = gridLayoutManager
            setHasFixedSize(true)
            vipFilterAdapter = VipFilterMoreAdapter(context)
            addItemDecoration(FilterDecoration(vipFilterAdapter, context))

            adapter = vipFilterAdapter
        }
    }

    override fun initData(): NewFilterMoreData? {
        vipFilterMoreData = NewFilterMoreData()
        vipFilterAdapter?.notifyDataSetChanged()

        return vipFilterMoreData
    }

    override fun setFilterSelected(searchFilterData: SearchFilterData?) {
        vipFilterAdapter?.setSearchFilterData(searchFilterData)
    }

    @OnClick(R.id.filter_clear, R.id.filter_confirm, R.id.transparent_filter_cancle)
    fun onViewClicked(view: View) {
        when (view.id) {
            R.id.filter_clear -> {
                setFilterSelected(null)
            }

            R.id.filter_confirm -> {
                cancel()
                if (onDismissListener != null) {
                    mData?.apply {
                        experience = vipFilterAdapter?.getSelectExperience()
                        preference = vipFilterAdapter?.getSelectPreference()
                        education = vipFilterAdapter?.getSelectEducation()
                        salaryLower = vipFilterAdapter?.getSelectSalaryValue(true)
                        salaryUpper = vipFilterAdapter?.getSelectSalaryValue(false)
                        selectSalaryTxt = vipFilterAdapter?.getSelectSalaryTxt()
                        jobHuntingStatus = vipFilterAdapter?.getSelectJobHuntingStatus()
                        ageLower = vipFilterAdapter?.getSelectAgeValue(true)
                        ageUpper = vipFilterAdapter?.getSelectAgeValue(false)
                        gender = vipFilterAdapter?.getSelectGender()
                        school = vipFilterAdapter?.getSelectSchool()
                        company = vipFilterAdapter?.getSelectCompany()
                        graduateTime = vipFilterAdapter?.getGraduateTime()
                        graduateAgoOrAfter = vipFilterAdapter?.getGraduateTimeBeforeOrAfter()
                        jobHoppingSearchModel = vipFilterAdapter?.getJobHoppingSearchModel()
                        famousOutSourcing = vipFilterAdapter?.getFamousOutSouring()
                        industryFields = vipFilterAdapter?.getIndustryFields()
                        period = vipFilterAdapter?.getSelectPeriod()
                        profName = vipFilterAdapter?.getSelectProfName()
                        isMoreExpand = vipFilterAdapter?.getIsMoreExpand()
                    }
                    onDismissListener.onConfirm(mData)
                    AnalyticHelper.getInstance().sendClickInfo("fR00", "1s6h")
                }
            }

            R.id.transparent_filter_cancle -> cancel()
            else -> {}
        }
    }
}
